API docs for “spamfighter.rules.validate”

# Module s.r.validate

Part of spamfighter.rules View Source

Модуль содержащий правила проверки сообщений

Class | regexpCheck | Правило проверки текст сообщение на соответствие регулярному выражению.
Function | lengthCheck | Правило проверки текста сообщение на минимальную и максимальную длину.
Function | attributeCheck | Правило проверки соответствия значения атрибута указанному значению.
Function | hasAttribute | Правило проверки наличия аттрибута у сообщения

def lengthCheck(domain, message, minLength=None, maxLength=None, attribute='text'): (source)
Правило проверки текста сообщение на минимальную и максимальную длину.

Parameters | domain | домен, относительно которого идёт анализ (type: `IDomain` )
| message | сообщение (type: `spamfighter.interfaces.IMessage` )
| attribute | имя атрибута сообщения, содержащего текст (type: `str` )
| minLength | минимальная длина сообщения (type: `int` )
| minLength | максимальная длина сообщения (type: `int` )

def attributeCheck(domain, message, attribute, value): (source)
Правило проверки соответствия значения атрибута указанному значению.

Parameters | domain | домен, относительно которого идёт анализ (type: `IDomain` )
| message | сообщение (type: `spamfighter.interfaces.IMessage` )
| attribute | имя атрибута сообщения для проверки на соответствие (type: `str` )
| value | значение для проверки на соответствие (type: `object` )

def hasAttribute(domain, message, attribute): (source)
Правило проверки наличия аттрибута у сообщения

Parameters | domain | домен, относительно которого идёт анализ (type: `IDomain` )
| message | сообщение (type: `spamfighter.interfaces.IMessage` )
| attribute | имя атрибута сообщения для проверки на наличие (type: `str` )